2026-03-18 Version: 1.5.0
- Support API FetchOAuthAuthenticationToken.
- Support API GenerateJwtAuthenticationToken.
- Support API ListAuthenticationTokens.
- Support API ObtainJwtAuthenticationTokenByDerivedShortToken.
- Support API ReinstateAuthenticationToken.
- Support API ReinstateAuthenticationTokenByConsumer.
- Support API RevokeAuthenticationToken.
- Support API RevokeAuthenticationTokenByConsumer.
- Support API ValidateAuthenticationToken.


2026-03-17 Version: 1.4.0
- Support API GenerateTokenByAuthorizationServer.


2026-03-17 Version: 1.3.1
- Generated python 2022-02-25 for Eiam-developerapi.

2026-02-12 Version: 1.3.0
- Support API ObtainCredential.


2026-01-20 Version: 1.2.0
- Support API ObtainCloudAccountRoleAccessCredential.


2025-12-03 Version: 1.0.10
- Update SDK.

2023-10-24 Version: 1.0.8
- Generated python 2022-02-25 for Eiam-developerapi.

2023-09-12 Version: 1.0.7
- Generated python 2022-02-25 for Eiam-developerapi.

2023-05-16 Version: 1.0.6
- Ceshi.

2022-11-28 Version: 1.0.5
- Ceshi.

2022-09-01 Version: 1.0.4
- Ceshi.

2022-08-19 Version: 1.0.3
- Ceshi.

2022-05-27 Version: 1.0.2
- Ceshi.

2022-05-25 Version: 1.0.1
- Ceshi.

2022-05-25 Version: 1.0.0
- Ceshi.

